function [phidT,phidA,phixT,W_hom_A,W_hom_T,W_het_A,W_het_T,XS] = LognGFT(mu,sigma,epsilon,fE,fX,fd,tau,x0)

% DESCRIPTION
% This function computes various quantities under the hypothesis of lognormal productivity distribution

% INPUTS:
% mu, sigma: parameters of the (lognormal) productivity distribution
% epsilon: elasticity of substitution
% fE: sunk entry costs
% fD, fX: fixed production and export costs
% tau: variable trade costs
% x0: starting point for the numerical optimization procedure

% OUTPUTS:
% phidT: productivity cutoff for serving the domestic market under the trade regime
% phidA: productivity cutoff for serving the domestic market under the autarky regime
% phixT: export productivity cutoff
% W_hom_A: welfare in the homogeneous firm model under the autarky regime
% W_hom_T: welfare in the homogeneous firm model under the trade regime
% W_het_T: welfare in the heterogeneous firm model under the trade regime
% XS: proportion of exporting firms

% USAGE: [phidT,phidA,phixT,W_hom_A,W_hom_T,W_het_A,W_het_T,XS] = LognGFT(mu,sigma,epsilon,fE,fX,fd,tau,x0);

% AUTHORS: Marco Bee, Department of Economics and Management, University of Trento; e-mail: marco.bee@unitn.it
%          Stefano Schiavo, School of International Studies and Department of Economics and Management, University of Trento and OFCE-DRIC; e-mail: stefano.schiavo@unitn.it
% This version: June 30, 2015

options = optimoptions('fsolve','Display','iter','maxfunevals',800000,'MaxIter',1000000,'TolFun',1e-10);

% Heterogeneous

[phidA,fval] = fsolve(@f_dom,x0,options,mu,sigma,epsilon,fE,fd) 
[phidT,fval1] = fsolve(@f_trade,x0,options,mu,sigma,epsilon,fE,fd,tau,fX) 
a0 = (log(phidA)-mu)/sigma;
W_het_A = (1/(epsilon*fd))^(1/(epsilon-1)) * ((epsilon-1)/epsilon) * phidA;
FA = fE/(1-logncdf(phidA,mu,sigma)) + fd;
phibar_A = (exp((epsilon-1)*mu+(epsilon-1)^2*sigma^2/2)*normcdf((epsilon-1)*sigma-a0)/normcdf(-a0))^(1/(epsilon-1));
select = tau*(fX/fd)^(1/(epsilon-1));
if select > 1
    phixT = tau * (fX/fd)^(1/(epsilon-1)) * phidT;
    chi = (1 - logncdf(phixT,mu,sigma)) ./ (1 - logncdf(phidT,mu,sigma));
    FT = fE/(1-logncdf(phidT,mu,sigma)) + fd + chi*fX;
    a0x = (log(phixT)-mu)/sigma;
    phibar_x = (exp((epsilon-1)*mu+(epsilon-1)^2*sigma^2/2)*normcdf((epsilon-1)*sigma-a0x)/normcdf(-a0x))^(1/(epsilon-1)); 
    a0d = (log(phidT)-mu)/sigma;
    phibar_d = (exp((epsilon-1)*mu+(epsilon-1)^2*sigma^2/2)*normcdf((epsilon-1)*sigma-a0d)/normcdf(-a0d))^(1/(epsilon-1));
    phibar_t = ((1/(1+chi)) * (phibar_d^(epsilon-1) + chi * (phibar_x/tau)^(epsilon-1)))^(1/(epsilon-1)); 
    W_het_T = (1/(epsilon*fd))^(1/(epsilon-1)) * ((epsilon-1)/epsilon) * phidT;
else
    phixT = phidT;
    chi = (1 - logncdf(phixT,mu,sigma)) ./ (1 - logncdf(phidT,mu,sigma));
    FT = fE/(1-logncdf(phidT,mu,sigma)) + fd + chi*fX;
    a0x = (log(phixT)-mu)/sigma;
    phibar_x = (exp((epsilon-1)*mu+(epsilon-1)^2*sigma^2/2)*normcdf((epsilon-1)*sigma-a0x)/normcdf(-a0x))^(1/(epsilon-1)); 
    a0d = (log(phidT)-mu)/sigma;
    phibar_d = (exp((epsilon-1)*mu+(epsilon-1)^2*sigma^2/2)*normcdf((epsilon-1)*sigma-a0d)/normcdf(-a0d))^(1/(epsilon-1));
    phibar_t = ((1/(1+chi)) * (phibar_d^(epsilon-1) + chi * (phibar_x/tau)^(epsilon-1)))^(1/(epsilon-1)); 
    W_het_T = ((1+tau^(1-epsilon)) / (epsilon*(fd+fX)))^(1/(epsilon-1)) * ((epsilon-1)/epsilon) * phidT;
end
XS = (1-logncdf(phixT,mu,sigma))/(1-logncdf(phidT,mu,sigma)); 

% Homogeneous

Fd = fd + fE/(1 - logncdf(phidA,mu,sigma));
W_hom_A = (1/(epsilon*Fd))^(1/(epsilon-1)) * ((epsilon-1)/epsilon) * phibar_A;
phibar2 = (.5 * (phibar_A^(epsilon-1)+(phibar_A/tau)^(epsilon-1)))^(1/(epsilon-1));
W_hom_T = (2/(epsilon*(Fd+fX))).^(1/(epsilon-1)) .* ((epsilon-1)/epsilon) .* phibar2;        
end

