function [GFT_het,GFT_hom,XS] = ParetoGFT(phiMin,alpha,epsilon,fE,fX,fd,tau)
% DESCRIPTION
% This function computes various quantities under the hypothesis of Weibull productivity distribution

% INPUTS:
% phiMIn, alpha: scale and shape parameters of the (Pareto) productivity distribution
% epsilon: elasticity of substitution
% fE: sunk entry costs
% fX, fd: fixed export and production costs
% tau: variable trade costs

% OUTPUTS:
% GFT_het: Gains From Trade in the heterogeneous firm model
% GFT_hom: Gains From Trade in the homogeneous firm model
% XS: proportion of exporting firms

% USAGE: [GFT_het,GFT_hom,XS] = ParetoGFT(phiMin,alpha,epsilon,fE,fX,fd,tau);

% AUTHORS: Marco Bee, Department of Economics and Management, University of Trento; e-mail: marco.bee@unitn.it
%          Stefano Schiavo, School of International Studies and Department of Economics and Management, University of Trento and OFCE-DRIC; e-mail: stefano.schiavo@unitn.it
% This version: June 30, 2015

% Heterogeneous

phidA = ((epsilon-1) / (alpha - (epsilon-1)) * fd/fE * phiMin^alpha)^(1/alpha);
phidT = ((epsilon-1) ./ (alpha - (epsilon-1)) * ((fd + tau.^(-alpha) * (fX/fd)^(-alpha/(epsilon-1)) * fX) / fE) * phiMin^alpha).^(1/alpha);
if tau*(fX/fd)^(1/(epsilon-1))>1
    phixT = (tau.^(epsilon-1) .* fX./fd .* phidT.^(epsilon-1)).^(1/(epsilon-1));
else
    phixT = phidT;
end
if epsilon > (log(fd/fX)+log(tau)) / log(tau)
    GFT_het = (1+(1./(tau*(fX/fd)^(1./(epsilon-1))))^alpha*fX/fd)^(1/alpha); 
else
    GFT_het = ((1+tau^(1-epsilon)*fd)/(fd+fX))^(1/(epsilon-1))*(1+fX/fd)^(1/alpha); 
end

% Homogeneous

Fd = fd + fE/((1/phidA)^alpha);
lambda_hom_T = 1./(1+tau.^(1-epsilon));       
GFT_hom = (Fd./(lambda_hom_T*(Fd+fX))).^(1/(epsilon-1)); 
GFT_hom = max([ones(1,length(GFT_hom)); GFT_hom]);
XS = ((phiMin/phixT)/(phiMin/phidT))^alpha; 
end

