function [phidT,phidA,phixT,W_hom_A,W_hom_T,W_het_A,W_het_T,XS] = WeibGFT(k,lambda,epsilon,fE,fX,fd,tau,x0)

% DESCRIPTION
% This function computes various quantities under the hypothesis of Weibull productivity distribution

% INPUTS:
% k, lambda: shape and scale parameters of the (Weibull) productivity distribution
% epsilon: elasticity of substitution
% fE: sunk entry costs
% fD, fX: fixed production and export costs
% tau: variable trade costs
% x0: starting point for the numerical optimization procedure

% OUTPUTS:
% phidT: productivity cutoff for serving the domestic market under the trade regime
% phidA: productivity cutoff for serving the domestic market under the autarky regime
% phixT: export productivity cutoff
% W_hom_A: welfare in the homogeneous firm model under the autarky regime
% W_hom_T: welfare in the homogeneous firm model under the trade regime
% W_het_T: welfare in the heterogeneous firm model under the trade regime
% XS: proportion of exporting firms

% USAGE: [phidT,phidA,phixT,W_hom_A,W_hom_T,W_het_A,W_het_T,XS] = WeibGFT(k,lambda,epsilon,fE,fX,fd,tau,x0);

% AUTHORS: Marco Bee, Department of Economics and Management, University of Trento; e-mail: marco.bee@unitn.it
%          Stefano Schiavo, School of International Studies and Department of Economics and Management, University of Trento and OFCE-DRIC; e-mail: stefano.schiavo@unitn.it
% This version: June 30, 2015

options = optimset('Display','none','TolFun',1e-10,'TolX',1e-10,'TolCon',1e-10,'MaxIter',5000,'MaxFunEvals',30000);

% Heterogeneous

[phidT,fval1] = fsolve(@f_trade_weib,x0,options,k,lambda,epsilon,fE,fd,fX,tau);
[phidA,fval2] = fsolve(@f_dom_weib,x0,options,k,lambda,epsilon,fE,fd); 
FA = fE/(1-wblcdf(phidA,lambda,k)) + fd;
phibar_A = (MWeibTrunc((epsilon-1),phidA,k,lambda))^(1/(epsilon-1));
W_het_A =  (epsilon-1)/epsilon * (phibar_A^(epsilon-1)/(epsilon*FA))^(1/(epsilon-1)); 
select = tau*(fX/fd)^(1/(epsilon-1));
if select > 1
    phixT = tau * (fX/fd)^(1/(epsilon-1)) * phidT;
    chi = (1 - wblcdf(phixT,lambda,k)) ./ (1 - wblcdf(phidT,lambda,k));
    FT = fE/(1-wblcdf(phidT,lambda,k)) + fd + chi*fX;
    phibar_x = (MWeibTrunc((epsilon-1),phixT,k,lambda))^(1/(epsilon-1)); 
    phibar_d = (MWeibTrunc((epsilon-1),phidT,k,lambda))^(1/(epsilon-1));
    phibar_t = ((1/(1+chi)) * (phibar_d^(epsilon-1) + chi * (phibar_x/tau)^(epsilon-1)))^(1/(epsilon-1)); 
    W_het_T = ((epsilon-1)/epsilon) * ((1+chi)/(epsilon*FT)*phibar_t^(epsilon-1))^(1/(epsilon-1));
else
    phixT = phidT;
    chi = (1 - wblcdf(phixT,lambda,k)) ./ (1 - wblcdf(phidT,lambda,k));
    FT = fE/(1-wblcdf(phidT,lambda,k)) + fd + chi*fX;
    phibar_x = (MWeibTrunc((epsilon-1),phixT,k,lambda))^(1/(epsilon-1)); 
    phibar_d = (MWeibTrunc((epsilon-1),phidT,k,lambda))^(1/(epsilon-1));
    phibar_t = ((1/(1+chi)) * (phibar_d^(epsilon-1) + chi * (phibar_x/tau)^(epsilon-1)))^(1/(epsilon-1)); 
    W_het_T = ((epsilon-1)/epsilon) * ((1+chi)/(epsilon*FT)*phibar_t^(epsilon-1))^(1/(epsilon-1));
end
XS = (1-wblcdf(phixT,lambda,k))/(1-wblcdf(phidT,lambda,k)); 

% Homogeneous

Fd = fd + fE/(1 - wblcdf(phidA,lambda,k));
W_hom_A = (1./(epsilon*Fd)).^(1/(epsilon-1)) .* ((epsilon-1)/epsilon) .* phibar_A;          
phibar2 = (.5 * (phibar_A^(epsilon-1)+(phibar_A/tau)^(epsilon-1)))^(1/(epsilon-1));
W_hom_T = (2/(epsilon*(Fd+fX))).^(1/(epsilon-1)) .* ((epsilon-1)/epsilon) .* phibar2;         
end

