function I = f_trade_weib(x,k,lambda,epsilon,f_e,f_d,f_x,tau)

% DESCRIPTION
% This function computes the free-entry condition in open economy under the
% assumption of Weibull-distributed productivity (equation A14, Appendix A)

% INPUTS:
% x: productivity cutoff for serving the domestic market under the trade regime
% k, lambda: shape and scale parameters of the (Weibull) productivity distribution
% epsilon: elasticity of substitution
% f_e: sunk entry costs
% f_d, f_x: fixed production and export costs
% tau: variable trade costs

% OUTPUT:
% I: value of the free entry condition

% USAGE: I = f_trade_weib(x,k,lambda,epsilon,f_e,f_d,f_x,tau);

% AUTHORS: Marco Bee, Department of Economics and Management, University of Trento; e-mail: marco.bee@unitn.it
%          Stefano Schiavo, School of International Studies and Department of Economics and Management, University of Trento and OFCE-DRIC; e-mail: stefano.schiavo@unitn.it
% This version: June 30, 2015

    cutoff = f_d/(tau^(epsilon-1)); 
    indici1 = find(f_x > cutoff);
    indici2 = find(f_x <= cutoff);
    if x<=0
        x = 1e-20;
    end
    phix(indici1) = tau*(f_x(indici1)/f_d)^(1/(epsilon-1))*x;     
    phix(indici2) = x;
    I1 = MWeibTrunc(epsilon-1,x,k,lambda);
    I2 = MWeibTrunc(epsilon-1,phix,k,lambda);
    I = f_e - f_d*(1-wblcdf(x,lambda,k)) * (I1/x^(epsilon-1)-1) - f_x*(1-wblcdf(phix,lambda,k)) * (I2/phix^(epsilon-1)-1);  
end
